export interface CreateTokenReq {
    /**
     * 用户头像，暂不实现，头像地址URI，支持base64编码格式
     */
    avatar?: string;
    /**
     * 客户端信息，客户端信息，如机型、操作系统、CPU等。
     */
    client?: Client;
    /**
     * p2p模式，为true时使用p2p模式。默认false
     */
    p2p?: boolean;
    /**
     * 平台，可选平台：Android \iOS \Windows \Web \Linux \Mac
     */
    platform?: Platform;
    /**
     * 角色，可选值：presenter\viewer\recorder，默认为presenter
     */
    role?: Role;
    /**
     * 房间名，不得为空
     */
    roomname: string;
    /**
     * sdk版本，如1.1.0.5
     */
    sdk?: string;
    /**
     * 用户ID，32位无符号，客户端值0~2147483647，若传0为服务端生成uid，服务端生成的uid为2147483648-4294967295。
     */
    uid?: number;
    /**
     * 用户名，用户名，utf-8编码格式
     */
    username?: string;
}
/**
 * 客户端信息，客户端信息，如机型、操作系统、CPU等。
 */
export interface Client {
    /**
     * 架构，如：arm64-v8a
     */
    arch?: string;
    /**
     * CPU型号
     */
    cpu?: string;
    /**
     * 内存大小，如：8.0G
     */
    memory?: string;
    /**
     * 设备机型，针对移动设备，比如：ANA-AN00；iPhone Xs Max
     */
    model?: string;
    /**
     * 系统版本，系统版本， 比如：Android 10,level 29；iOS 15.2 (19C56)
     */
    os: string;
    /**
     * 安卓ROM，比如：HuaWei/EMOTION
     */
    rom?: string;
    /**
     * 浏览器用户代理信息，比如：Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/105.0.0.0 Safari/537.36
     */
    ua?: string;
}
/**
 * 平台，可选平台：Android \iOS \Windows \Web \Linux \Mac
 */
export declare enum Platform {
    Android = "Android",
    Darwin = "Darwin",
    IOS = "iOS",
    Linux = "Linux",
    Web = "Web",
    Windows = "Windows"
}
/**
 * 角色，可选值：presenter\viewer\recorder，默认为presenter
 */
export declare enum Role {
    Presenter = "presenter",
    Recorder = "recorder",
    Viewer = "viewer"
}
export interface CreateTokenRsp {
    /**
     *
     * WS连接地址，长连接服务地址，如"192.168.20.22:3000"，"wss://leiartc.com"。连接的协议体现在host地址上，默认为ws协议，目前支持ws和wss两种协议。支持域名；端口可默认，ws默认为80，wss默认为443。
     */
    host: string;
    /**
     * 备选Host列表
     */
    optionalHosts?: string[];
    /**
     * p2p模式，表示房间是否开启p2p模式。若不返回该值，可认为p2p为false。对于服务端来说，p2p为true或实际值与请求值不匹配时应该要返回给参数
     */
    p2p?: boolean;
    /**
     * 服务端的房间id，定位bug
     */
    roomId?: string;
    /**
     * 签名信息，用于长连接的校验
     */
    signature: string;
    /**
     * WS连接的token，用于长连接的校验
     */
    tokenId: string;
    /**
     * 用户信息
     */
    userInfo: UserInfo;
    /**
     * 服务端api版本，如1.0.0
     */
    version: string;
}
/**
 * 用户信息
 */
export interface UserInfo {
    /**
     * 用户头像
     */
    avatar?: string;
    /**
     * 角色
     */
    role: Role;
    /**
     * 用户ID，32位无符号，返回非0值，要么等于客户端值1~2147483647，若由服务端生成uid，值为2147483648-4294967295。
     */
    uid: number;
    /**
     * 用户名，可以为空
     */
    username?: string;
}
