import { ClientConfig, ClientEvent, ConnectionState, ILeiaRTCClient, ILeiaRTCRemoteUser, ILocalTrack, IRemoteTrack, LowStreamParameter, RemoteStreamType, SubscribeOptions, UID } from '../core/types';
import { Emitter } from '../utils/emitter';
export interface LeiaRTCClient {
    emit<T extends keyof ClientEvent>(e: T, ...args: Parameters<ClientEvent[T]>): void;
}
export declare class LeiaRTCClient extends Emitter implements ILeiaRTCClient {
    uid: number;
    connectionState: ConnectionState;
    channelName: string;
    localTracks: ILocalTrack[];
    remoteUsers: ILeiaRTCRemoteUser[];
    private config;
    private socketClient;
    private connectionMap;
    private userStreamMap;
    private remoteTracks;
    private mediaStreamToSend;
    private dualStreamOptions;
    private iceServers;
    private forceIceRelayMode;
    private userNeedSEIMap;
    constructor(config: ClientConfig);
    join(appId: string, channel: string, appKey: string | null, uid?: number | null): Promise<number>;
    leave(): Promise<void>;
    private negotiateWithServer;
    publish(tracks: ILocalTrack | ILocalTrack[]): Promise<void>;
    unpublish(tracks?: ILocalTrack | ILocalTrack[]): Promise<void>;
    private getRemoteUserTracks;
    private setRemoteUserTrack;
    subscribe(user: ILeiaRTCRemoteUser, mediaType: 'video' | 'audio', options?: SubscribeOptions): Promise<IRemoteTrack>;
    /**
     * 解析用户的视频流SEI
     * @param uid 用户id
     * @private
     */
    private resolveSEI;
    unsubscribe(user: ILeiaRTCRemoteUser, mediaType?: 'video' | 'audio'): Promise<void>;
    enableAudioVolumeIndicator(): void;
    private disableAudioVolumeIndicator;
    enableDualStream(): Promise<undefined>;
    disableDualStream(): Promise<void>;
    setLowStreamParameter(streamParameter: LowStreamParameter): void;
    setRemoteDefaultVideoStreamType(streamType: RemoteStreamType): Promise<void>;
    setRemoteVideoStreamType(uid: UID, streamType: RemoteStreamType): Promise<void>;
    private cantPublish;
    private cantUnPublish;
    private initJoinedUsers;
    private deleteUserStream;
    private bindServerNoticeEvents;
    private switchConnectionState;
    replaceMediaTrack(track: MediaStreamTrack): Promise<void>;
}
