import { Emitter } from '../utils/emitter';
import { ConstrainLong, ICameraVideoTrack, ILocalAudioTrack, ILocalTrack, ILocalVideoTrack, IMicrophoneAudioTrack, IRemoteAudioTrack, IRemoteTrack, IRemoteVideoTrack, ITrack, LocalTrackEvent, UID, VideoEncoderConfiguration, VideoEncoderConfigurationPreset, VideoPlayerConfig } from '../core/types';
import { LeiaRTCClient } from '../core/client';
export declare class Track extends Emitter implements ITrack {
    protected id: string;
    protected mediaTrack: MediaStreamTrack;
    protected mediaElement?: HTMLMediaElement;
    private mediaContainer?;
    trackMediaType: "audio" | "video";
    isPlaying: boolean;
    constructor(type: 'audio' | 'video', mediaTrack: MediaStreamTrack);
    getTrackId(): string;
    getMediaStreamTrack(): MediaStreamTrack;
    play(element?: string | HTMLElement): void;
    stop(): void;
    clearMediaElement(): void;
    setMediaTrack(mediaTrack: MediaStreamTrack): void;
    getMediaContainer(): HTMLElement;
}
export interface LocalTrack {
    emit<T extends keyof LocalTrackEvent>(e: T, ...args: Parameters<LocalTrackEvent[T]>): void;
}
export declare class LocalTrack extends Track implements ILocalTrack {
    muted: boolean;
    enabled: boolean;
    protected publishedClients: LeiaRTCClient[];
    constructor(type: 'audio' | 'video', mediaTrack: MediaStreamTrack);
    protected bindTrackEvent(): void;
    protected unbindTrackEvent(): void;
    getTrackLabel(): string;
    close(): void;
    addPublishedClient(client: LeiaRTCClient): void;
    removePublishedClient(client: LeiaRTCClient): void;
    setEnabled(enabled: boolean): Promise<undefined>;
    setMuted(muted: boolean): Promise<void>;
}
declare class LocalAudioTrack extends LocalTrack implements ILocalAudioTrack {
    protected originAudioTrack: MediaStreamTrack;
    constructor(mediaTrack: MediaStreamTrack);
    setVolume(volume: number): void;
    getVolumeLevel(): number;
    play(): void;
    close(): void;
}
export declare class LocalVideoTrack extends LocalTrack implements ILocalVideoTrack {
    private encodeConfig?;
    constructor(mediaTrack: MediaStreamTrack);
    play(element: string | HTMLElement, config?: VideoPlayerConfig): void;
    getCurrentFrameData(): ImageData;
    saveEncodeConfig(config: VideoEncoderConfiguration): void;
    getEncodeConfig(): {
        width?: number | ConstrainLong | undefined;
        height?: number | ConstrainLong | undefined;
        frameRate?: number | ConstrainLong | undefined;
        bitrateMin?: number | undefined;
        bitrateMax?: number | undefined;
    } | undefined;
}
export declare class MicrophoneAudioTrack extends LocalAudioTrack implements IMicrophoneAudioTrack {
    private deviceId;
    constructor(mediaTrack: MediaStreamTrack);
    setDevice(deviceId: string): Promise<void>;
    setEnabled(enabled: boolean): Promise<undefined>;
}
export declare class CameraVideoTrack extends LocalVideoTrack implements ICameraVideoTrack {
    private deviceId;
    constructor(mediaTrack: MediaStreamTrack);
    setDevice(deviceId: string): Promise<void>;
    setEnabled(enabled: boolean): Promise<undefined>;
    setEncoderConfiguration(config: VideoEncoderConfiguration | VideoEncoderConfigurationPreset): Promise<void>;
}
declare class RemoteTrack extends Track implements IRemoteTrack {
    private readonly userId;
    constructor(type: 'audio' | 'video', mediaTrack: MediaStreamTrack, userId: UID);
    getUserId(): UID;
}
export declare class RemoteAudioTrack extends RemoteTrack implements IRemoteAudioTrack {
    private volumeLevel;
    constructor(mediaTrack: MediaStreamTrack, userId: UID);
    setVolume(volume: number): void;
    getVolumeLevel(): number;
    play(): void;
}
export declare class RemoteVideoTrack extends RemoteTrack implements IRemoteVideoTrack {
    constructor(mediaTrack: MediaStreamTrack, userId: UID);
    play(element: string | HTMLElement, config?: VideoPlayerConfig): void;
    getCurrentFrameData(): ImageData;
}
export declare const isVideoTrack: (t: ITrack) => boolean;
export declare const isAudioTrack: (t: ITrack) => boolean;
export declare const hasVideoTrack: (tracks: ITrack[]) => boolean;
export declare const hasAudioTrack: (tracks: ITrack[]) => boolean;
export {};
