/**
 * 事件监听器基类
 * const e = new Emitter()
 * e.on('eventA', callback) // 监听eventA
 * e.emit('eventA', ...) // 触发eventA
 */
export declare class Emitter {
    private callbackCollection;
    /**
     * 检查是否有重复的监听函数
     * @param queue 监听函数队列
     * @param callback 需要查重的监听函数
     * @private
     */
    private checkRepeatCallback;
    /**
     * 将监听函数添加到事件对应的队列
     * @param event 监听的事件
     * @param callback 监听函数
     * @private
     */
    private addCallback;
    /**
     * 对事件进行监听
     * @param event 要监听的事件
     * @param callback 监听函数
     */
    on(event: string, callback: unknown): void;
    /**
     * 取消监听事件的某回调函数
     * @param {string} event 事件名
     * @param {function} callback 回调函数
     */
    off(event: string, callback: unknown): void;
    /**
     * 取消指定事件所有监听函数，或者取消所有事件的监听函数
     * @param {string} event 事件名
     */
    removeAllListeners(event?: string): void;
    /**
     * 触发事件对应的监听函数
     * @param event 事件
     * @param args 传入监听函数的参数
     */
    emit(event: string, ...args: unknown[]): void;
}
